@@ -40,7 +40,6 @@ class FPS:
 
 
 async def checkTerminatorQueue(opqueue):
-
     while True:
 
         data = await opqueue.get()
@@ -402,5 +401,13 @@ class GSPeerConnectionBroadcasterUniversalNew:
             connectURL = self.gsdbs.credentials["signalserver"]
 
         await self.sio.connect(
-            f'{connectURL}?gssession={self.gsdbs.cookiejar.get("session")}.{self.gsdbs.cookiejar.get("signature")}&target={self.target}')
+            f'{connectURL}?gssession={self.gsdbs.cookiejar.get("session")}.{self.gsdbs.cookiejar.get("signature")}&target={self.target}&terminator=true')
         await self.sio.wait()
+
+
+def createTerminatorView(gsdbs, aioqueue: asyncio.Queue, target):
+    return asyncio.gather(checkTerminatorQueue(aioqueue),
+                          GSPeerConnectionBroadcasterUniversalNew.create(gsdbs=gsdbs,
+                                                                         target=target + "terminatorview",
+                                                                         videostream=False,
+                                                                         videotrack=True))
